@@ -1,4 +1,11 @@
-from django.template import Context
+from django.http import HttpRequest
+from django.template.context import RenderContext
+
+
+class InterfaceNotFound(Exception):
+    """Interface with this name was not found"""
+
+    pass
 
 
 class ITemplatePluginMixin:
@@ -12,11 +19,8 @@ class ITemplatePluginMixin:
     template_name: str = ""
     context: dict = {}
 
-    def get_context(self, context: Context) -> Context:
+    def get_plugin_context(self):
         """Override this method to add custom context to the plugin.
 
-        :param context: the context that is passed from the template
-            where this plugin is rendered.
-        """
-        context.update(self.context)
-        return context
+        Per default, it only returns ``self.context``"""
+        return self.context
