@@ -15,11 +15,11 @@ class __EmptyMutation(graphene.ObjectType):
     """Empty GraphQL mutation"""
 
 
-"""A Graphene query object that collects all plugins' Graphene query objects."""
+"""A global Graphene query object that collects all plugins' Graphene query objects."""
 GDAPSQuery = None
 
 GDAPSMutation = None
-"""A Graphene mutation object that collects all plugins' Graphene mutation objects."""
+"""A global Graphene mutation object that collects all plugins' Graphene mutation objects."""
 
 PluginManager.load_plugin_submodule("schema")
 
